package com.docus.server.collect.controller;

import com.docus.core.util.json.JSON;
import com.docus.log.annotation.TrackGroup;
import com.docus.log.context.TrackHelper;
import com.docus.server.collect.service.CollectService;
import com.docus.server.sys.common.pojo.dto.UserDTO;
import com.docus.server.visitor.VisitorProcessor;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * @author wen yongbin
 * @date 2023年2月25日21:56:33
 * @see com.docus.server.collect.infrastructure.dao.CollectTypeEnum 枚举
 * @see com.docus.server.ws.convert.IConverter 通用转化器
 * @see com.docus.server.ws.IWsResult 通用返回结果
 * @see VisitorProcessor 通用处理器
 */
@Slf4j
@RestController
@Api(value = "用户管理接口", tags = "用户管理接口")
@RequestMapping("/api/http/user")
public class PowerUserController {
    protected final static String DEL_TYPE = "D";
    @Resource
    private CollectService collectService;

    /**
     * 被动http 用户信息接收，进行操作
     *
     * @param message 接收到的用户参数
     * @return 返回结果
     */
    @ApiOperation("新增/编辑用户(根据id)")
    @PostMapping("/update")
    @TrackGroup(
        group = "HTTP_PASSIVE_USER",
        beanNames = {"powerUserConverter", "httpResultAdapter"},
        processor = VisitorProcessor.class)
    public String httpPassiveUser(String message) {
        log.debug("新增/修改用户数据：{}", message);
        collectService.insertOrUpdateUser(JSON.fromJSON((String) TrackHelper.getValue("jsonStr"), UserDTO.class));
        return null;
    }


}
